=== modified file 'bzrlib/tests/blackbox/test_update.py'
--- bzrlib/tests/blackbox/test_update.py	2006-07-31 14:16:29 +0000
+++ bzrlib/tests/blackbox/test_update.py	2006-07-31 14:31:56 +0000
@@ -18,7 +18,9 @@
 
 """Tests for the update command of bzr."""
 
+import os
 
+from bzrlib import branch, bzrdir
 from bzrlib.tests import TestSkipped
 from bzrlib.tests.blackbox import ExternalBase
 from bzrlib.workingtree import WorkingTree
@@ -147,3 +149,48 @@
         self.failUnlessExists('checkout/file_b')
         self.failUnlessExists('checkout/file_c')
         self.assertTrue(wt.has_filename('file_c'))
+
+    def test_update_with_merges(self):
+        # Test that 'bzr update' works correctly when you have
+        # an update in the master tree, and a lightweight checkout
+        # which has merged another branch
+        master = self.make_branch_and_tree('master')
+        self.build_tree(['master/file'])
+        master.add(['file'])
+        master.commit('one', rev_id='m1')
+
+        self.build_tree(['checkout1/'])
+        checkout_dir = bzrdir.BzrDirMetaFormat1().initialize('checkout1')
+        branch.BranchReferenceFormat().initialize(checkout_dir, master.branch)
+        checkout1 = checkout_dir.create_workingtree('m1')
+
+        # Create a second branch, with an extra commit
+        other = master.bzrdir.sprout('other').open_workingtree()
+        self.build_tree(['other/file2'])
+        other.add(['file2'])
+        other.commit('other2', rev_id='o2')
+
+        # Create a new commit in the master branch
+        self.build_tree(['master/file3'])
+        master.add(['file3'])
+        master.commit('f3', rev_id='m2')
+
+        # Merge the other branch into checkout
+        os.chdir('checkout1')
+        self.run_bzr('merge', '../other')
+
+        self.assertEqual(['o2'], checkout1.pending_merges())
+
+        # At this point, 'commit' should fail, because we are out of date
+        self.run_bzr_error(["please run 'bzr update'"],
+                           'commit', '-m', 'merged')
+
+        # This should not report about local commits being pending
+        # merges, because they were real merges
+        out, err = self.run_bzr('update')
+        self.assertEqual('', out)
+        self.assertEqual('All changes applied successfully.\n'
+                         'Updated to revision 2.\n', err)
+
+        # The pending merges should still be there
+        self.assertEqual(['o2'], checkout1.pending_merges())

